#####Assignment 1#####
########Group_1########
####AppendixII_code.R###

#libraries
library(readxl)
library(tidyverse)
library(dplyr)
library(psych)
library(xtable)
library(ggpubr)
library(effectsize) 
library(car)

#set working directory
#insert file path
setwd(fp)

#Import data
data <- as.data.frame (read_xlsx("groep1.xlsx"))

#Assign number to observations
data$id_participant<-1:nrow(data)
row.names(data)<-data[,5]

#Rename targetemreg with labels: 1 = control, 2 = suppression, 3 = expression
data$targetemreg <- factor(data$targetemreg, levels = c(1,2,3), labels = c("control", "suppression", "expression"))
data$gender <- factor(data$gender, levels = c(1,2), labels = c("men", "women"))

##############################  
######### Question 1 #########  
############################## 

#general descriptives 
summary(data)

#check descriptives by group
tapply(data$appropriate, data$targetemreg, summary)
tapply(data$appropriate, data$targetemreg, sd)


#Plot appropriateness ratings by condition

ggline(data, x = "targetemreg", y = "appropriate", palette = c("#E7B800","#00AFBB"), add = "mean_se", ) + ylim(2,6)

#One-way ANOVA to look for mean differences in appropriateness ratings by condition
ANOVA = aov(data$appropriate ~ data$targetemreg )
summary(ANOVA)#F(2,87) = 7.084, p = 0.0014
#At least one group significantly differs in  appropriateness scores 

#Effect size using the omega square  
Fval = summary(ANOVA)[[1]][1,4]
pval = summary(ANOVA)[[1]][1,5]
SSeff = summary(ANOVA)[[1]][1,2]
SStot = summary(ANOVA)[[1]][1,2]+summary(ANOVA)[[1]][2,2]
MSerr = summary(ANOVA)[[1]][2,3]
dfeff = summary(ANOVA)[[1]][1,1]
r.sq = SSeff/SStot #r-square effect size: 0.14
om.sq = (SSeff - dfeff*MSerr)/(SStot + MSerr) # omega square effect size: 0.11 we can consider it low             


#Bootstrap to calculate omega^2 CI

a<- 3
#compute errors
data[data$targetemreg =="expression",6] <- data[data$targetemreg=="expression",2]-mean(data[data$targetemreg=="expression",2])
data[data$targetemreg =="suppression",6] <- data[data$targetemreg=="suppression",2]-mean(data[data$targetemreg== "suppression",2])
data[data$targetemreg =="control",6] <- data[data$targetemreg=="control",2]-mean(data[data$targetemreg== "control",2])
colnames(data)[6] <- "Errors"

nBoot <- 10000
omega2 <- 0
M_expression <- mean(data[data$targetemreg=="expression",2])
M_suppression <- mean(data[data$targetemreg== "suppression",2])
M_control <- mean(data[data$targetemreg== "control",2])


for (i in 1:nBoot) {
  # sample errors from observations and add them to group means
  temp_expression <- M_expression + matrix(c(sample(data$Errors, size = length(data$Errors[data$targetemreg=="expression"]),replace=T)),ncol = 1)
  temp_suppression <- M_suppression + matrix(c(sample(data$Errors, size = length(data$Errors[data$targetemreg=="suppression"]),replace=T)),ncol = 1)
  temp_control <- M_control + matrix(c(sample(data$Errors, size = length(data$Errors[data$targetemreg=="control"]),replace=T)),ncol = 1)
  
  # compute omega
  
  SSE_reduced <- sum((c(temp_expression,temp_suppression, temp_control) - mean(c(temp_expression,temp_suppression, temp_control)))^2)
  SSE_full <- sum((temp_expression-M_expression)^2) + sum((temp_suppression-M_suppression)^2) + sum((temp_control-M_control)^2)
  SSE_ff <- SSE_reduced - SSE_full
  MSE_full <- SSE_full / (length(temp_expression) + length(temp_suppression) + length(temp_control)- a) #check that i defined a before
  omega2[i] <- (SSE_ff - (a-1) * MSE_full) / (SSE_reduced + MSE_full)
}

hist(omega2,breaks = 100, freq = F, main = NULL,xlab=expression(paste(omega^2)))
quantile(omega2, c(.025,.975)) # 95% Confidence interval:-0.04023863  0.23654730 , no effect or small efect


#---- CHECKING ASSUMPTIONS -------


#check outliers 
#gives numbers outside the interval I=[q0.25???1.5???IQR;q0.75+1.5???IQR]
out <- boxplot.stats(data$appropriate)$out #out = the values of any data points which lie beyond the extremes of the whiskers
out_ind <- which(data$appropriate %in% c(out))
out_ind
data[out_ind, ] #using this method there seems to be 14 outliers


#frequency distribution of the appropriateness scores 
ggplot(data) +
  aes(x = appropriate) +
  geom_histogram(bins = 30L, fill = "#0c4c8a") +
  theme_minimal()
#there seems to be heavy tails

#Normality assumption check (QQ-plot) 
qqnorm(ANOVA$residuals) # plot residuals
qqline(ANOVA$residuals)
x <- seq(-5,5,len = 100) # plot standard normal function
lines(x,x,col="red") #data seems normal 
#normality seems to hold

##homoscedasticity (residual plot) by group  
ggplot(data) +
  aes(x = targetemreg, y = ANOVA$residuals) +
  geom_point() 
#there seems to be homogeneity of variances

#---- PLANNED CONTRASTS -------

#Since we have two planned contrasts form the same family we use the bonferroni correction

P<-2 #planned contrasts
alpha_FW<- .05/P
df_full<-nrow(data)-a

#hypothesis 1: appropriateness ratings of suppression condition will be different from the ratings of expression and control condition.

n_by_group= table(data$targetemreg)
mean_by_group = tapply(data$appropriate, data$targetemreg, mean)
cc1=c(-.5,1,-.5) # coefficients: control (-.5), supression(1), express(-.5)
g1 = sum(cc1*mean_by_group) # estimate
seg1 = sqrt(MSerr)*sqrt(sum( cc1^2/n_by_group) ) # standard error 
t1=g1/seg1 # t statistic = 3.75
p1=2*min(pt(t1,df_full),1-pt(t1,df_full) ) # two sided p value(0.0003) <  alpha_FW(0.025), suppression condition is significantly higher than the average of control and expression
d.t1 = g1 / sqrt(MSerr) # Cohen s d = 0.8396713 (large effect size)

#Bonferonni simultaneous CI
quantile <- 1-(alpha_FW/(2*P))
t_CI<- qt(quantile,df_full) * seg1
CI <- c(g1-t_CI, g1+t_CI) #0.2337856 1.2239922
print(CI)

#Hypothesis 2: we expect expression condition scores to be different than control condition scores   
n_by_group=table(data$targetemreg)
nmean_by_group = tapply(data$appropriate, data$targetemreg, mean)
cc2=c(1,0,-1) # coefficients: control (1), supression(0), express(-1) 
g2 = sum(cc2*mean_by_group) # estimate
seg2 = sqrt(MSerr)*sqrt(sum( cc2^2/n_by_group) ) # standard error 
t2=g2/seg2 # t statistic = 0.25
p2=2*min(pt(t2,df_full),1-pt(t2,df_full) ) # two sided p value(0.7971831) > alpha_FW(0.025), there is no significant difference between expression and control condition
d.t2 = g2 / sqrt(MSerr) # Cohen s d (0.06655931), no effect size

#Bonferonni simultaneous CI
quantile <- 1-(alpha_FW/(2*P))
t_CI2<- qt(quantile,df_full) * seg2
CI2 <- c(g2-t_CI2, g2+t_CI2) #-0.5139182  0.6294738
print(CI2)


#---- ANALYSIS WITHOUT OUTLIERS -------


#Anova
data_wo_outliers <- data[-as.numeric(out_ind), ]
xtabs(~data_wo_outliers$targetemreg) #control: 29, suppression:21, expression: 26 
ANOVA.5 <- aov(data_wo_outliers$appropriate~ data_wo_outliers$targetemreg)
summary(ANOVA.5) #F(2,73) = 8.47, p = 0.0004


#Effect size
Fval = summary(ANOVA.5)[[1]][1,4]
pval = summary(ANOVA.5)[[1]][1,5]
SSeff = summary(ANOVA.5)[[1]][1,2]
SStot = summary(ANOVA.5)[[1]][1,2]+summary(ANOVA)[[1]][2,2]
MSerr = summary(ANOVA.5)[[1]][2,3]
dfeff = summary(ANOVA.5)[[1]][1,1]
r.sq = SSeff/SStot #r-square effect size: 0.08
om.sq = (SSeff - dfeff*MSerr)/(SStot + MSerr) # omega square effect size: 0.078 we can consider it low  
print(om.sq)

#---- PLANNED CONTRASTS WITHOUT OUTLIERS-------

#Since we have two planned contrasts form the same family we use the bonferroni correction

P<-2 #planned contrasts
alpha_FW<- .05/P
df_full<-nrow(data_wo_outliers)-a

#hypothesis 1: appropriateness ratings of suppression condition will be different from the ratings of expression and control condition.

n_by_group= table(data_wo_outliers$targetemreg)
mean_by_group = tapply(data_wo_outliers$appropriate, data_wo_outliers$targetemreg, mean)
cc1=c(-.5,1,-.5) # coefficients: control (-.5), supression(1), express(-.5)
g1 = sum(cc1*mean_by_group) # estimate
seg1 = sqrt(MSerr)*sqrt(sum( cc1^2/n_by_group) ) # standard error 
t1=g1/seg1 # t statistic = 4.05
p1=2*min(pt(t1,df_full),1-pt(t1,df_full) ) # two sided p value(0.0001) <  alpha_FW(0.025), suppression condition is significantly different than the average of control and expression
d.t1 = g1 / sqrt(MSerr) # Cohen s d = 1.04 (large effect size)

#Bonferonni simultaneous CI
quantile <- 1-(alpha_FW/(2*P))
t_CI<- qt(quantile,df_full) * seg1
CI <- c(g1-t_CI, g1+t_CI) #0.2337856 1.2239922
print(CI)

#Hypothesis 2: we expect expression condition scores to be different than control condition scores   
n_by_group=table(data_wo_outliers$targetemreg)
nmean_by_group = tapply(data_wo_outliers$appropriate, data_wo_outliers$targetemreg, mean)
cc2=c(1,0,-1) # coefficients: control (1), supression(0), express(-1) 
g2 = sum(cc2*mean_by_group) # estimate
seg2 = sqrt(MSerr)*sqrt(sum( cc2^2/n_by_group) ) # standard error 
t2=g2/seg2 # t statistic = -0.5671421
p2=2*min(pt(t2,df_full),1-pt(t2,df_full) ) # two sided p value(0.5723575) > alpha_FW(0.025), there is no significant difference between expression and control condition
d.t2 = g2 / sqrt(MSerr) # Cohen s d (-0.1531749), no/small effect size

#Bonferonni simultaneous CI
quantile <- 1-(alpha_FW/(2*P))
t_CI2<- qt(quantile,df_full) * seg2
CI2 <- c(g2-t_CI2, g2+t_CI2) #-0.5225624  0.3330840
print(CI2)


##############################  
######### Question 2 #########  
##############################   

#Check if the design is balanced for the two way ANOVA
xtabs(~data$targetemreg+data$gender) #it is balanced
m <- 15 #for all groups

#descriptive statistics
ggboxplot(data, x = "targetemreg", y = "appropriate", fill =  "gender", palette = c("#E7B800","#00AFBB")) #we see a few outliers

#explore interaction effect
ggline(data, x = "targetemreg", y = "appropriate", color = "gender",palette = c("#E7B800","#00AFBB"), add = "mean_se")

#Multifactorial anova to check for intercation
ANOVA2 <- aov(data$appropriate~ data$targetemreg *data$gender)
summary(ANOVA2) #pvalue( 0.100177)> alpha(.05) thus we can't reject the null hypothesis. No interaction found.

#effect sizes for main effect of emotion regulation condition and gender 
effectsize(ANOVA2, type = "omega") #ER condition: .13; gender : 0.04 (both very low) 

#---- CHECKING ASSUMPTIONS -------



#Outliers
out <- boxplot.stats(data$appropriate)$out #out = the values of any data points which lie beyond the extremes of the whiskers
out_ind <- which(data$appropriate %in% c(out))
out_ind
data[out_ind, ] #using this method there seems to be 14 outliers



#Normality assumption check (QQ-plot) 
qqnorm(ANOVA2$residuals) # plot residuals
qqline(ANOVA2$residuals)
x <- seq(-5,5,len = 100) # plot standard normal function
lines(x,x,col="red") #data seems normal 

hist(ANOVA$residuals)

##homoscedasticity (residual plot) 
plot(ANOVA2$fitted.values,ANOVA2$residuals, main = 'Residuals', xlab = 'Fitted', ylab = 'Residuals', color = 2)
abline(h=0)  
#there seems to be homogeneity of variances but some outliers

##homoscedasticity (residual plot) by group 
data$ANOVA2_residuals <- c(ANOVA2$residuals)
wom_appropriate <- as.data.frame(data[data$gender == "women", 1:7])
men_appropriate <- as.data.frame(data[data$gender == "men", 1:7])

ggplot(wom_appropriate) +
  aes(x = targetemreg, y = ANOVA2_residuals) +
  geom_point() +
  ggtitle("women")

ggplot(men_appropriate) +
  aes(x = targetemreg, y = ANOVA2_residuals) +
  geom_point() 
ggtitle("men")

leveneTest(data$appropriate ~ data$targetemreg*data$gender, data = data) #F(5,84) = 2.2913, p = 0.052


## Independence: research design between participants, we assume they have been selected randomly (no cluster effect) and they have not been measured multiple times 

#analysis without the outliers 
data_wo_outliers <- data[-as.numeric(out_ind), ]
xtabs(~data_wo_outliers$targetemreg +data_wo_outliers$gender) 
ANOVA3 <- aov(data_wo_outliers$appropriate~ data_wo_outliers$targetemreg *data_wo_outliers$gender)
summary(ANOVA3) #F(2,70) = 0.021, p=.97, no interaction effect, the results are similar to the analysis with the outliers

