#import data
groep_5<-read.table("groep5.csv",header=TRUE,sep=",")
attach(groep_5)
library(car)

#descriptive analyse of age for methods part
summary(age)
print(var(age))
print(sd(age))

#import factor
groep_5$targetemreg<-factor(groep_5$targetemreg)
groep_5$gender<-factor(groep_5$gender)
table(groep_5$targetemreg,groep_5$gender)

# fit a linear model
appro_lm<-lm(appropriate~gender*targetemreg,data=groep_5,contrasts=list(gender=contr.sum, targetemreg=contr.sum))

#use boxplot to show results of all groups and detect outliners
boxplot(appropriate~gender*targetemreg,data=groep_5,frame = FALSE, 
        col = c('white','grey'), xlab="targetmerg,gender",ylab="appropriate",
        names=c("male,control","female,control","male,supression",
                "female,supression","male,expression","female,expression"))

#analysis with outliers (see Appendix)

#check assumptions of normality
qqnorm(appropriate)
hist(appropriate,xlab="appropriate score")

##check assumption of homoscedasticity 
#residual plot
plot(jitter(appro_lm$fitted.values,10),appro_lm$residuals,ylab = 'Residuals',xlab = 'Fitted value')
#Levene's test
leveneTest(appropriate~gender*targetemreg, data = groep_5)

##TYPE1 ANOVA with outliers
mod_appro<-Anova(appro_lm)
print(mod_appro)

#EFFECT SIZE
library(sjstats)
anova_stats(mod_appro)

#contrasts & simple effect
library(emmeans)
#contrast for the main effect of targetemreg
emmeans::emmeans(appro_lm, pairwise~targetemreg, adjust="Tukey")
#simple effect test_by targetemreg
emmeans::joint_tests(appro_lm, by = 'targetemreg')


##remove the outliers (results in the text)

#group the data and then calculate 25th & 75th percentile as well as interquantile.
library(dplyr)
Q <- groep_5 %>%
  select(appropriate,targetemreg,gender) %>%
  group_by(targetemreg,gender) %>%
  summarise(quantile_1 = quantile(appropriate,probs = .25),
            quantile_2 = quantile(appropriate,probs = .75),
            iqr = IQR(appropriate))
#calculate the upper and lower range
up <- Q$quantile_2 [2] + 1.5*Q$iqr[1]
low <- Q$quantile_1 [1] - 1.5*Q$iqr[1]
#remove outliers.
b = 0
delete_index <- c()
for (i in 1:90){
  if(groep_5$targetemreg[i] ==1 && groep_5$gender[i] == 2 && (groep_5$appropriate[i] < low || groep_5$appropriate[i] > up) ){
    a = i
    delete_index = c(delete_index,a)
  }else{
    b = b + 1
  }
}
groep_5_cleaned <- groep_5[-delete_index,]

#descriptive statistics for each cell
descr_data <- groep_5_cleaned %>%
  select(appropriate,targetemreg,gender) %>%
  group_by(targetemreg,gender) %>%
  summarise(mu_cell = mean(appropriate),sd = sd(appropriate)) 


appro_cleaned_lm<-lm(appropriate~gender*targetemreg,data=groep_5_cleaned,contrasts=list(gender=contr.sum, targetemreg=contr.sum))
#check assumptions of normality
qqnorm(groep_5_cleaned$appropriate)
hist(groep_5_cleaned$appropriate,xlab="appropriate scaore")
##check assumption of homoscedasticity 
#residual plot
plot(jitter(appro_cleaned_lm$fitted.values,10),appro_cleaned_lm$residuals,ylab = 'Residuals',xlab = 'Fitted value')
#Levene's test
leveneTest(appropriate~gender*targetemreg, data = groep_5_cleaned)

#ANOVA without outliers.
mod_appro_cleaned<-Anova(appro_cleaned_lm,type=3)
print(mod_appro_cleaned)

#EFFECT SIZE
anova_stats(mod_appro_cleaned)

#contrasts & simple effect
#simple effect test_by targetemreg
emmeans::joint_tests(appro_cleaned_lm, by = 'targetemreg')
#contrast for the main effect of targetemreg
emmeans::emmeans(appro_cleaned_lm, pairwise~targetemreg,adjust="Tukey")

