# Assignment I : STATISTICS IV

###################
# Clear workspace
rm(list = ls())
###################

# Packages
# install.packages("ggpubr")
# install.packages("readxl")
# install.packages("dplyr")
# install.packages("tidyverse")
# install.packages("boot)

library(ggpubr)
library(readxl)
library(dplyr)
library(ggplot2)
library(boot)

# Reading the data
################################################################################
groep7 <- read_excel("C:/Users/Public/Documents/groep7.xlsx")
groep7$targetemreg <- as.factor(groep7$targetemreg) # Converted Emotional Conditions to factors
groep7$gender <- as.factor(groep7$gender) # Converted Gender to factors
groep7$gender_label <- recode(groep7$gender, "1" = "Male", "2" = "Female") # Added labels for gender
groep7$condition <- recode(groep7$targetemreg, "1" = "Control", 
                           "2" = "Suppression", "3" = "Expression") # Added labels for the condition
apt_score_cont <- groep7[groep7[1] == 1,2, drop = TRUE] # Control Condition (1)
apt_score_sup <- groep7[groep7[1] == 2,2, drop = TRUE] # Suppression Condition (2)
apt_score_exp <- groep7[groep7[1] == 3,2, drop = TRUE]  # Expression Condition (3)
################################################################################

# Descriptive Statistics
################################################################################
# Box Plot:
ggplot(groep7, aes(x = condition, y = appropriate)) + 
  labs(x = "Experimental Condition", y = "Appropriateness Score", 
       title = "Appropriateness vs Condition") +
  geom_boxplot(fill='steelblue') + theme_classic2()
################################################################################

# Males and Females
male_count_1a <- nrow(subset(groep7, gender == 1)) # 45
female_count_1a <- nrow(subset(groep7, gender == 2)) # 45
# There are 45 males and 45 females in the experiment.

# Means
mean_age <- mean(groep7$age) # 36.75556
mean_apt_score <- mean(groep7$appropriate) # 4.260741 # Overall mean appropriateness score
mean_apt_score_cont <- mean(apt_score_cont) # 4.12 # Control condition mean appropriateness score
mean_apt_score_sup <- mean(apt_score_sup) # 4.733333 # Suppression condition mean appropriateness score
mean_apt_score_exp <- mean(apt_score_exp) # 3.928889 # Expression condition mean appropriateness score
# Standard Deviations
sd_apt_score <- sd(groep7$appropriate) # 0.9198949
sd_apt_score_cont <- sd(apt_score_cont) # 0.871938
sd_apt_score_sup <- sd(apt_score_sup) # 0.793653
sd_apt_score_exp <- sd(apt_score_exp) # 0.9172562
################################################################################

# Visualizing the data
################################################################################
ggboxplot(groep7, x = "condition", y = "appropriate", color = "gender_label",
          xlab = "Experimental Condition", ylab = "Appropriateness Score",
          title = "Appropriateness ~ Condition + Gender",
          palette = c("#00AFBB", "#E7B800"))
################################################################################

# Assumptions
################################################################################
# Assumption 1. Normality
plot(lm(appropriate ~ targetemreg, data=groep7), which = 2)
# Appropriateness scores are normally distributed.

# Assumption 2. Homoscedasticity
################################################################################
# Residuals vs Fitted values plot --> Data seems homoscedastic.
plot(lm(appropriate ~ targetemreg, data=groep7), which = 1)

# 3. Assumption 3 // Checking outliers (using Cook's Distance)
################################################################################
reg_1a <- lm(appropriate ~ targetemreg, data = groep7)
cooksd_1a <- cooks.distance(reg_1a)
# Plot the Cook's Distance using the 4/n criterion
sample_size <- nrow(groep7)
plot(cooksd_1a, pch ="*", cex = 2, main = "Outliers using Cook's distance", 
     xlab = "Index", ylab = "Cook's Distance")  # Plot Cook's distance
abline(h = 4/sample_size, col = "red")  # add cutoff line
text(x = 1:length(cooksd_1a)+1, y = cooksd_1a, 
     labels = ifelse(cooksd_1a > 4/sample_size, 
                     names(cooksd_1a),""), col="red")  # add labels
# We see 4 outliers based on the 4/n criterion.
outliers_1a <- as.numeric(names(cooksd_1a)[(cooksd_1a > (4/sample_size))]) # 38 39 55 90
# Will deal with these in the additional analysis for Appendix III.
################################################################################

#' *1. A) Difference between the conditions - 1-way ANOVA (F-test)*
################################################################################
aov_1a <- aov(appropriate ~ condition, data = groep7)
summary_aov_1a <- summary(aov_1a) # F(2,87) = 7.124, p = 0.00136

# Post-hoc Testing
tukey_1a <-TukeyHSD(aov_1a)
tukey_1a
par(mar = (c(3,12,3,2))) # Adjusting for names to be visible in the plot
plot(tukey_1a, las = 1, col = "black")
par(mar = (c(5.1,4.1,4.1,2.1))) # Back to normal margins
# Interpretation:
# Difference between Suppression and Control groups is significant.
# The difference between Expression and Control groups is not significant.
# Difference between Expression and Suppression groups is significant.

# Effect Size
################################################################################
# (I) R^2
r_sq <- function(data, i) {
  mydata <- data[i,]
  r.sq <- summary(lm(appropriate ~ condition, data = mydata))$r.square
  return(r.sq)
}

r_sq_1a <- r_sq(groep7) # 0.1407248 // 14% variance explained

# 95% Bootstrap Interval for r.sq (10000 simulations)
set.seed(123)
bootstrap_rsq <- boot(groep7,r_sq,R=10000)
plot(bootstrap_rsq)
boot.ci(boot.out = bootstrap_rsq, type = "norm")

# 95% Confidence Interval for r.sq is (-0.0081,0.2558) 
################################################################################

# (II) Omega^2
################################################################################
omega_sq <- function(data, i) {
  mydata <- data[i,]
  aovm <- aov(appropriate ~ condition, data = mydata)
  sum_stats <- summary(aovm)[[1]]
  SSm <- sum_stats[["Sum Sq"]][1]
  SSr <- sum_stats[["Sum Sq"]][2]
  DFm <- sum_stats[["Df"]][1]
  MSr <- sum_stats[["Mean Sq"]][2]
  W2 <- (SSm-DFm*MSr)/(SSm+SSr+MSr)
  return(W2)
}

om.sq_1a <- omega_sq(groep7) # 0.1197882

# 95% Bootstrap Interval for om.sq (10000 simulations)
################################################################################
set.seed(123)
bootstrap_omsq <- boot(groep7,omega_sq,R=10000)
plot(bootstrap_omsq)
boot.ci(boot.out = bootstrap_omsq, type = "norm")
# 95% Confidence Interval for om.sq is (-0.0313,0.2366).
################################################################################

# Based on the F-value F(2,87) = 7.124, and the p-value (0.00136), we can conclude that 
# there's evidence for a significant differences in the appropriateness score 
# for the 3 conditions.
# Emotional expression explains around 14% of the variance in the appropriateness scores.

# Interpretation:
# So, it seems that the the response of people who suppressed their positive emotions
# was judged differently from the response of people expressing their positive emotions 
# and persons without instruction.

# Rank ANOVA 1.A)
ranks_1a <- rank(groep7$appropriate, ties.method = "average")
data_rank_1a <- data.frame(ranks_1a, groep7$targetemreg)
colnames(data_rank_1a) <- c("ranks", "condition")
anova_rank_1a <-aov(ranks ~ condition, data_rank_1a)
summary(anova_rank_1a) # F(2,87) = 7.095, p = 0.0014
################################################################################

#' *1.B) Difference between Expression Condition (3) and Control Condition (1)*
################################################################################
# Cohen's d
cohens_d <- function(data, i) {
  mydata <- data[i,]
  aovm <- aov(appropriate ~ condition, data = mydata)
  apt_score_cont <- mydata[mydata[1] == 1,2, drop = TRUE]
  apt_score_exp <- mydata[mydata[1] == 3,2, drop = TRUE]
  g <- mean(apt_score_exp) - mean(apt_score_cont)
  MS_err <- summary(aovm)[[1]][["Mean Sq"]][2]
  sigma <- sqrt(MS_err)
  d <- g / sigma
  return(d)
}
cohens_d_1b <- cohens_d(groep7) # -0.221588 // Original
# The effect size (reported as Cohen's d) is small (d = -0.221588).

# 95% Bootstrap Interval for cohen's d (10000 simulations)
################################################################################
set.seed(123)
bootstrap_cohens_d <- boot(groep7,cohens_d,R=10000)
plot(bootstrap_cohens_d)
boot.ci(boot.out = bootstrap_cohens_d, type = "norm")
# 95% Confidence Interval for Cohen's d is (-0.7665,0.3288) 
################################################################################

# Assuming equal variances - 2 Sample t test
t_1b_eq_var <- t.test(apt_score_exp, apt_score_cont, var.equal = TRUE) 
# t = -0.82711, df = 58, p-value = 0.4116

# Assuming unequal variances - Welch Two Sample t-test
t_1b_uneq_var <- t.test(apt_score_exp, apt_score_cont, var.equal = FALSE)
# t = -0.82711, df = 57.852, p-value = 0.4116

# ANOVA
data_1b <- data.frame(list(appropriateness=c(apt_score_exp, apt_score_cont)), 
                      condition = rep(c("expression", "control"), 
                                      times = c(length(apt_score_exp), length(apt_score_cont))))
aov_1b <- aov(appropriateness ~ condition, data = data_1b)
summary(aov_1b) # F(1,58) = 0.684, p = 0.412

# Verification:
(t_1b_eq_var$statistic)^2 # 0.684, same as the F value from ANOVA. (F = t^2 for two groups)

# Based on the F-value F(1,58) = 0.684, and the p-value (0.412), it seems that 
# there isn't sufficient evidence for a difference specifically between 
# the expression and control conditions in terms of their appropriateness scores.
################################################################################

# Rank ANOVA 1.B)
ranks_1b <- rank(c(apt_score_exp, apt_score_cont), ties.method = "average")
data_rank_1b <- data.frame(ranks_1b, rep(c("expression", "control"), 
                                         times = c(length(apt_score_exp), length(apt_score_cont))))
colnames(data_rank_1b) <- c("ranks", "condition")
anova_rank_1b <-aov(ranks ~ condition, data_rank_1b)
summary(anova_rank_1b) # F(1,58) = 0.421, p = 0.519

# Similar conclusion can be reached using the Rank ANOVA for the two conditions.
################################################################################

#' *2. Impact of Gender and condition on the appropriateness response*
################################################################################
# Plot:
# Scatter plot:
ggplot(groep7, aes(x = condition, y = appropriate, colour = gender_label)) +
  labs(x = "Experimental Condition", y = "Appropriateness Score") + 
  labs(title = "Appropriateness ~ Condition + Gender") + 
  geom_jitter(width = 0.1) + theme_classic2()

# Means Plot to see interaction
summary_data <- as.data.frame(groep7 %>%
                                group_by(condition, gender_label) %>%
                                summarise_at(vars("appropriate"), mean))
names(summary_data)[3] <- "Appropriateness_Mean"

summary_data$Appropriateness_S.D. <- (as.data.frame(groep7 %>% 
                                                      group_by(condition, gender_label) %>% 
                                                      summarise_at(vars("appropriate"), sd)))$appropriate

# Condition on X-axis, Appropriateness on Y-axis
ggplot(summary_data, aes(x = condition, y = Appropriateness_Mean, colour = gender_label)) + 
  labs(x = "Experimental Condition", y = "Mean Appropriateness Score") +
  labs(title = "Appropriateness ~ Condition + Gender") +
  geom_point(size = 4, shape = 1) + geom_line(aes(group = gender_label)) + theme_classic2()

# Gender on X-axis, Appropriateness on Y-axis
ggplot(summary_data, aes(x = gender_label, y = Appropriateness_Mean, colour = condition)) + 
  labs(x = "Gender", y = "Mean Appropriateness Score") + 
  labs(title = "Appropriateness ~ Condition + Gender") +
  geom_point(size = 4, shape = 1) + geom_line(aes(group = condition)) + theme_classic2()

# We don't see much interaction, so Type I Sum of Squares (default in R) should be safe to use.
# 2-way ANOVA with interaction
model_2a <- lm(appropriate ~ targetemreg + gender + targetemreg:gender, data = groep7)
aov_2a <- anova(model_2a)
summary(aov_2a)

# There seems to be almost no interaction between gender and emotional condition, as we can
# see from the plots above. F(2,84) = 0.2369, p = 0.789606
# For Emotional condition (targetemreg), there is evidence of a main effect 
# (F(2,84) = 7.0827, p = 0.001437).
# The main effect of gender does not seem to be significant. (F(1,84) = 2.0214, p = 0.158802).

# R^2 value (explained variance)
################################################################################
ss_main_condition <- aov_2a[["Sum Sq"]][1] # 10.59832
ss_main_gender <- aov_2a[["Sum Sq"]][2] # 1.512346
ss_interaction <- aov_2a[["Sum Sq"]][3] # 0.3544691
ss_full <- aov_2a[["Sum Sq"]][4] # 62.84726

r.sq_2a_condition <- ss_main_condition / (ss_main_condition + ss_full) # 0.1443017 // 14%
r.sq_2a_gender <- ss_main_gender / (ss_main_gender + ss_full) # 0.02349837 // 2%
r.sq_2a_interaction <- ss_interaction / (ss_interaction + ss_full) # 0.005608535 // 0.56%
r.sq_overall <- summary(model_2a)$r.square # 0.1655124

# The experimental condition explains around 14% of the total variance in the 
# appropriateness scores. Gender accounts for only 2% of the variance, while
# the variance accounted for by the interaction between condition and gender
# is almost negligible (0.56%).
################################################################################

# 2-way ANOVA without interaction
model_2b <- lm(appropriate ~ targetemreg + gender, data = groep7)
aov_2b <- anova(model_2b)
aov_2b
# Shows almost identical results for the main effects of condition and gender.
################################################################################

#' *Appendix III - Additional Analysis without Outliers*
################################################################################
# We used Cook's distance to remove outliers, with cutoff at 4/sample size.
data_wo_outliers <- groep7[-outliers_1a, ]

# 1.A) 1-Way ANOVA
aov_1a_out <- aov(appropriate ~ condition, data = data_wo_outliers)
summary(aov_1a_out) 
# F(2,83) = 12.71, p = 1.53e-05 without outliers.
# F(2,87) = 7.124, p = 0.00136 with outliers.
# The overall conclusion doesn't change after removing outliers.

# Post-hoc Testing
tukey_1a_out <-TukeyHSD(aov_1a_out)
par(mar = (c(3,12,3,2))) # Adjusting for names to be visible in the plot
plot(tukey_1a_out, las = 1, col = "black")
par(mar = (c(5.1,4.1,4.1,2.1))) # Back to normal margins
# Interpretation:
# Difference between Suppression and Control groups is significant.
# The difference between Expression and Control groups is not significant.
# Difference between Expression and Suppression groups is significant.
# Removing outliers does not have an impact on the conclusion drawn.

# Effect Size
################################################################################
# (I) R^2
r.sq_1a_out <- r_sq(data_wo_outliers) # 0.2344241 // 23.4% variance explained
# r.sq = 0.1407248 with outliers
# r.sq = 0.2344241 without outliers
# The proportion of explained variance goes up after removing outliers.

# 95% Bootstrap Interval for r.sq (10000 simulations)
set.seed(123)
bootstrap_rsq_out <- boot(data_wo_outliers,r_sq,R=10000)
par(mar = (c(5.1,4.1,4.1,2.1)))
plot(bootstrap_rsq_out)
boot.ci(boot.out = bootstrap_rsq_out, type = "norm")

# 95% Confidence Interval for r.sq is (0.0849, 0.3607) without outliers.
# 95% Confidence Interval for r.sq is (-0.0081,  0.2558 ) with outliers.
################################################################################

# (II) Omega^2
################################################################################
om.sq_1a_out <- omega_sq(data_wo_outliers) # 0.2140026

# 95% Bootstrap Interval for om.sq (10000 simulations)
set.seed(123)
bootstrap_omsq_out <- boot(data_wo_outliers,omega_sq,R=10000)
plot(bootstrap_omsq_out)
boot.ci(boot.out = bootstrap_omsq_out, type = "norm")

# 95% Confidence Interval for om.sq is (0.0618, 0.3424) without outliers.
# 95% Confidence Interval for om.sq is (-0.0313,0.2366) with outliers.
################################################################################

# Rank ANOVA 1.A
ranks_1a_out <- rank(data_wo_outliers$appropriate, ties.method = "average")
data_rank_1a_out <- data.frame(ranks_1a_out, data_wo_outliers$targetemreg)
colnames(data_rank_1a_out) <- c("ranks", "condition")
anova_rank_1a_out <-aov(ranks ~ condition, data_rank_1a_out)
summary(anova_rank_1a_out) 
# F(2,83) = 11.7, p = 3.35e-05 without outliers.
# F(2,87) = 7.095, p = 0.0014 with outliers.
# The F value goes up slightly after removing outliers.

# 1. B)
apt_score_cont_out <- data_wo_outliers[data_wo_outliers[1] == 1,2, drop = TRUE] # Control Condition (1)
apt_score_sup_out <- data_wo_outliers[data_wo_outliers[1] == 2,2, drop = TRUE] # Suppression Condition (2)
apt_score_exp_out <- data_wo_outliers[data_wo_outliers[1] == 3,2, drop = TRUE]  # Expression Condition (3)

# Cohen's d
cohens_d_1b_out <- cohens_d(data_wo_outliers) # -0.2479505

# The effect size (reported as Cohen's d) is small (d = -0.221588) without outliers.
# The effect size (reported as Cohen's d) is small (d = -0.2479505) with outliers.

# Additional Analysis : t-test
# Assuming equal variances - 2 Sample t test
t_1b_eq_var_out <- t.test(apt_score_exp_out, apt_score_cont_out, var.equal = TRUE) 

# t = -0.54656, df = 55, p-value = 0.5869 without outliers.
# t = -0.82711, df = 58, p-value = 0.4116 with outliers.
# Not much of a difference.

# Assuming unequal variances - Welch Two Sample t-test
t_1b_uneq_var_out <- t.test(apt_score_exp_out, apt_score_cont_out, var.equal = FALSE)
# t = -0.54825, df = 53.981, p-value = 0.5858 without outliers.
# t = -0.82711, df = 57.852, p-value = 0.4116 with outliers.
# Not much of a difference.

# ANOVA
data_1b_out <- data.frame(list(appropriateness=c(apt_score_exp_out, apt_score_cont_out)), 
                          condition = rep(c("expression", "control"), 
                                          times = c(length(apt_score_exp_out), length(apt_score_cont_out))))
aov_1b_out <- aov(appropriateness ~ condition, data = data_1b_out)
summary(aov_1b_out) 
# F(1,55) = 0.299, p = 0.587 without outliers.
# F(1,58) = 0.684, p = 0.412 with outliers.
# F value for the two group comparison goes down after removing outliers.
# However, the difference for the two conditions is still statistically insignificant.

# Verification:
(t_1b_eq_var_out$statistic)^2 # 0.299, same as the F value from ANOVA. (F = t^2 for two groups)

# Rank ANOVA 1.B)
ranks_1b_out <- rank(c(apt_score_exp_out, apt_score_cont_out), ties.method = "average")
data_rank_1b_out <- data.frame(ranks_1b_out, rep(c("expression", "control"), 
                                                 times = c(length(apt_score_exp_out), length(apt_score_cont_out))))
colnames(data_rank_1b_out) <- c("ranks", "condition")
anova_rank_1b_out <-aov(ranks ~ condition, data_rank_1b_out)
summary(anova_rank_1b_out) 
# F(1,55) = 0.198, p = 0.658 without outliers.
# F(1,58) = 0.421, p = 0.519 with outliers.
# Not much different.

# 2.
model_out <- lm(appropriate ~ targetemreg + gender + targetemreg:gender, data = data_wo_outliers)
aov_out <- anova(model_out)
summary(aov_out)

# R^2 value (explained variance)
################################################################################
ss_main_condition_out <- aov_out[["Sum Sq"]][1] # 15.09851
ss_main_gender_out <- aov_out[["Sum Sq"]][2] # 0.6091398
ss_interaction_out <- aov_out[["Sum Sq"]][3] # 0.03584005
ss_full_out <- aov_out[["Sum Sq"]][4] # 48.66333

r.sq_condition_out <- ss_main_condition_out / (ss_main_condition_out + ss_full_out) # 0.2367954 // 23.7%
r.sq_gender_out <- ss_main_gender_out / (ss_main_gender_out + ss_full_out) # 0.01236268 // 1%
r.sq_interaction_out <- ss_interaction_out / (ss_interaction_out + ss_full_out) # 0.0007359479 // 0.07%
r.sq_overall_out <- summary(model_out)$r.square # 0.2444383

# The experimental condition explains around 23.7% of the total variance in the 
# appropriateness scores. Gender accounts for only 1% of the variance, while
# the variance accounted for by the interaction between condition and gender
# is almost negligible (0.07%).
# Without removing the outliers, we had similar results for the main effect of 
# gender and the interaction effect. However, the proportion of variance explained
# by the experimental condition goes up significantly (from 14% to 24%) after 
# removing the outliers.
################################################################################

# Main effect of condition:
# F(2,80) = 12.4106, p = 2.021e-05  without outliers.
# F(2,84) = 7.0827,  p = 0.001437 with outliers.

# Main effect of gender:
# F(1,80) = 1.0014, p = 0.320 without outliers.
# F(1,84) = 2.0214, p = 0.158802 with outliers.

# Interaction between condition and gender:
# F(2,80) = 0.0295, p = 0.971 without outliers.
# F(2,84) = 0.2369, p = 0.789606 with outliers.
