####Data Preperation
library("tidyverse")
library("readxl")
library("dplyr")
library("rstatix")
library("stats")
library("ggpubr")
library("car")
library("purrr")
library("MASS")
library("multcomp")
library("outliers")
library("lsr")
library("moments")
library("officer")
library("apaTables")


my_data <- read_excel(file.choose())
attach(my_data)

class(targetemreg) #class is numeric so we change to categorical (factor)
targetemreg1 <- targetemreg 
targetemreg_factor <- factor(targetemreg1)
class(targetemreg_factor)

gender1 <- gender
gender_factor <- factor(gender1)
class(gender_factor)

appropriate1 <- appropriate

new_data <- data_frame(appropriate1, targetemreg_factor, gender_factor)

####Descriptive statistics
###Appropriate
mean(appropriate)
sd(appropriate)


###Appropriate~Targetemreg
group_by(my_data, targetemreg) %>% 
  summarise(
    n = n(),
    M = mean(appropriate, na.rm = TRUE),
    SD = sd(appropriate, na.rm = TRUE))

###Gender
group_by(my_data, gender) %>% 
  summarize (
    n=n())

###Age
M_age <- mean (age)
SD_age <- sd(age)


####Visualize data

ggboxplot(my_data, x = "targetemreg", y = "appropriate", 
          color = "targetemreg", palette = c(4,2,7),
          ylab = "Appropriateness", xlab = "Emotion Regulation Condition")

ggline(new_data, x = "targetemreg_factor", y = "appropriate1", 
       add = c("mean_se", "jitter"), color = "gender_factor",
       ylab = "Appropriateness", xlab = "Emotion Regulation Condition")

###Exporting the graphs
gg_boxplot<- ggboxplot(my_data, x = "targetemreg", y = "appropriate", 
                       color = "targetemreg", palette = c(4,2,7),
                       ylab = "Appropriateness", 
                       xlab = "Emotion Regulation Condition")
ggsave('image1.png',gg_boxplot, width=4, height = 3,units = "in")

gg_line<- ggline(new_data, x = "targetemreg_factor", y = "appropriate1", 
                 add = c("mean_se", "jitter"), color = "gender_factor",
                 ylab = "Appropriateness", 
                 xlab = "Emotion Regulation Condition")
ggsave('image2.png',gg_line, width=4, height = 3,units = "in")


####Assumption check
###Equality of Variance

#### H0 = There is not a statistically significant difference in perceived appropriateness between each of the three levels of the emotion regulation condition 
#### H1 = There is a statistically significant difference in perceived appropriateness between each of the three levels of the emotion regulation condition 

##For one-way ANOVA
leveneTest(appropriate ~  targetemreg_factor, data = my_data)

##For two-way ANOVA
leveneTest(appropriate ~  gender_factor, data = my_data)

###Normality
shapiro.test(my_data$appropriate)
qqPlot(appropriate)

###Outliers
my_data %>%
  group_by(targetemreg) %>%
  identify_outliers("appropriate")

#####Question one (one-way ANOVA)
one_anova <- aov(appropriate ~ targetemreg_factor, data = my_data) 
summary(one_anova)
etaSquared(one_anova, type = 2, anova = TRUE)

multiple <- glht(one_anova, linfct = mcp(targetemreg_factor = "Tukey"))
multiple
summary(multiple)

###Normality for residuals
qqnorm(one_anova$residuals) 
shapiro.test(one_anova$residuals)

####Post-hoc
TukeyHSD(one_anova)

####Question 2 (two-way ANOVA)

#### H0 = There is not an interaction effect between the individuals’ gender and the emotion regulation condition, which can predict the variation in the assessment of appropriateness
#### H1 = There is an interaction effect between the individuals’ gender and the emotion regulation condition, which can predict the variation in the assessment of appropriateness

two_anova <- aov(appropriate ~ targetemreg_factor + gender_factor + 
                   targetemreg_factor:gender_factor, data = my_data)
summary(two_anova)
etaSquared(two_anova, type = 2, anova = TRUE)

###Normality for residuals
qqnorm(two_anova$residuals) 
shapiro.test(two_anova$residuals )

####Post-hoc
TukeyHSD(two_anova)

####Additional Testing
###For Violation of Normality
##Alternative to one-way ANOVA
kruskal.test(appropriate ~ targetemreg_factor, data = my_data)

#Post-hoc
dunn_test(my_data, appropriate ~ targetemreg) 

###Remove outlier
data_out_rm <- my_data[!my_data %in% boxplot.stats(appropriate)$out]
length(my_data) - length(data_out_rm) ###count the difference
boxplot(data_out_rm) # Create boxplot without outliers


#find Q1, Q3, and interquartile range for values in column Appropriate
Q1 <- quantile(appropriate, .25)
Q3 <- quantile(appropriate, .75)
IQR <- IQR(appropriate)

#only keep rows in dataframe that have values within 1.5*IQR of Q1 and Q3
no_outliers <- subset(my_data, appropriate> (Q1 - 1.5*IQR) 
                      & appropriate< (Q3 + 1.5*IQR))

#view row and column count of new data frame
dim(no_outliers) 

###Creating tables
apa.aov.table(aov(appropriate ~ targetemreg_factor, data = my_data),filename = "Table4.doc",table.number = 1)
apa.aov.table(aov(appropriate ~ targetemreg_factor  + gender_factor + targetemreg_factor:gender_factor , data = my_data),filename = "Table5.doc",table.number = 2)

detach(my_data)

