# QUESTION 1
# Cleaning environment
rm(list = ls())
# Import packages 
require(car)
require(ggplot2)
require(plyr)
require(DescTools)
# Setting directory and loading the file
#setwd('Documents/Datasets statistics four')
require('readxl')
data <- read_excel('groep11.xlsx')
# Setting variables
a = 3 # groups for emotion regulation
b = 2 # groups for gender
n = 90 # total amount of participants
# Creating names for the emotion regulation groups and the genders
data$targetemregnames <- as.vector(factor(data$targetemreg, labels = c('Control', 'Suppression', 
'Expression')))
data$gendernames <- as.vector(factor(data$gender, labels = c('Male', 'Female'))) # 1 = Male, 2 = Female
# Subsetting the data for each condition in Emotion regulation
control_subset <- subset(data, targetemregnames == 'Control')
expression_subset <- subset(data, targetemregnames == 'Expression')
suppression_subset <- subset(data, targetemregnames == 'Suppression')
# Visualizing the data
ggplot(data = data, aes(x = as.factor(targetemregnames), y = appropriate)) +
  geom_boxplot(fill = 'steelblue', color = 'black') +
  labs( x = 'Emotion regulation', y = 'Appropriate level', title = 'Appropriate levels by emotion regulation 
conditions')
# Shows us the boxplots for the 3 different conditions, as we can see there are big outliers in the control condition and small outliers in the suppression condition
# Calculating one way ANOVA for question 1.1
aov_all <- aov(appropriate ~ targetemregnames, data = data)
summary(aov_all)
# The 3 conditions differ with a F-value of 10.16 and a p value of 0.000108 ***
# Code to compare the 2 contrasts 
mean_cond <- tapply(data$appropriate, data$targetemregnames, mean) #condition specific means
MSE_full <- summary(aov_all)[[1]][2, 3] # from the anova table
df_full <- summary(aov_all)[[1]][2, 1]
n_cond <- table(data$targetemregnames)
coefficients_1 <- c(-.5, -.5, 1) # coefficients for (control, expression, suppression)
g1 <- sum(coefficients_1 * mean_cond) 
SE_g1 <- sqrt(MSE_full) * sqrt(sum(coefficients_1^2/n_cond) ) 
t1 <- g1/SE_g1 
p1 <- 2 * min(pt(t1, df_full), 1-pt(t1, df_full)) # two sided p value
coefficients_2 <- c(-1, 1, 0) # coefficients for (control, expression, suppression)
g2 <- sum(coefficients_2 * mean_cond) 
SE_g2 <- sqrt(MSE_full) * sqrt(sum( coefficients_2^2/n_cond)) 
t2 <- g2/SE_g2 
p2 <- 2 * min(pt(t2, df_full), 1-pt(t2, df_full)) 
# Bonferroni correction on the 2 planned contrasts
bon_cor_two <- function (p_value) {
  p_bonferroni <- 0.05 / 2 # familywise alfa = 0.05, and P = 2
  bon <- p_value <= p_bonferroni
  return(bon) #Returns True when p-value is smaller than the bonferroni correction
}
# Creating a dataframe of the p-values with a boolean operator whether they are significant or not
p_val_contrasts <- c(p1, p2)
bonferroni_corrected <- tapply(p_val_contrasts, c('p1', 'p2'), bon_cor_two) # applying the function on the 2 p-values
bonferroni_corrected
#Bonferroni confidence interval
CI_1 <- data.frame('Confidence Interval' = 'Contrast 1',
                   'Lower' = g1 - (qt(p = 0.9875, df = df_full) * SE_g1), # 95% CI for contrast 1 with alfa/2P = 0.0125
                   
                   'Upper' = g1 + (qt(p = 0.9875, df = df_full) * SE_g1))
CI_2 <- data.frame('Confidence Interval' = 'Contrast 2',
                   
                   'Lower' = g2 - (qt(p = 0.9875, df = df_full) * SE_g2), # 95% CI for contrast 1 with alfa/2P =  0.0125
                   
                   'Upper' = g2 + (qt(p = 0.9875, df = df_full) * SE_g2))
conf_intervals_1 <- rbind(CI_1, CI_2)
conf_intervals_1
# Extracting the values and calculating proportion variance explained
SS_tot <- summary(aov_all)[[1]][1, 2] + summary(aov_all)[[1]][2, 2]
SS_ff <- summary(aov_all)[[1]][1, 2]
MSE_full <- summary(aov_all)[[1]][2, 3]
# Calculate omega squared
omega <- (SS_ff - (a - 1) * MSE_full) / (SS_tot + MSE_full) # unbiased variance explained
# ASSUMPTION CHECKS
# Homoscedasticity
# Histogram of residuals
hist(aov_all$residuals, main = 'Residuals', xlab = 'Residuals')
# Residual plot
ggplot(data, aes(x = as.factor(targetemregnames), y = aov_all$residuals)) + 
  geom_jitter(width = 0.2, alpha = 0.7, color = 'steelblue') +
  labs( x = "Fitted", y = "Residuals") +
  geom_hline(yintercept=0,linetype="dashed")
# If we include the outliers homoscedasticity seems not to be violated, but without the outliers the variability in the control and in the suppression group is smaller than in the expression group
# Normality
# QQ plot
qqnorm(aov_all$residuals) # plot residuals
qqline(aov_all$residuals)
x <- seq(-5,5,len = 100) # plot standard normal function
lines(x,x,col="red")
# Normality assumption seems to hold
# END QUESTION 1 
# QUESTION 2
# Subsetting the data based on gender
male_subset <- subset(data, gendernames == 'Male')
female_subset <- subset(data, gendernames == 'Female')
# Visualizing the data
ggplot(data = data, aes(x = as.factor(targetemregnames), y = appropriate, fill = gendernames)) +
  geom_boxplot() +
  labs( x = 'Emotion regulation', y = 'Appropriate level')
# From the plot it looks like there will be a main effect of gender (F > M) and a main effect of emotion regulation (Supp > control & expression), an interaction effect is difficult to see, we will check all these effects using an ANOVA
# 2 way ANOVA type I since the design is balanced
# Checking for interaction
aov_interaction <- aov(appropriate ~ targetemregnames * gendernames, data = data)
summary(aov_interaction)
# There is no significant interaction between emotion regulation and gender, F = 1.509, with p 0.22696
# So we us the additive 2 way ANOVA to further investigate the contrasts
aov_2way <- aov(data = data, appropriate ~ targetemregnames + gendernames)
summary(aov_2way)

# Here we find a main effect of emotion regulation with F = 11.211 and p = 0.0000471 ***
# There is also a main effect of gender with F = 9.987 and p = 0.00218 **
# Code to compare the 2 contrasts 
# Means for each group (emotion regulation by gender)
mean_cond_male <- tapply(male_subset$appropriate, male_subset$targetemregnames, mean) #condition specific means for males
mean_cond_female <- tapply(female_subset$appropriate, female_subset$targetemregnames, mean) # condition specific means for females
MSE_full_2 <- summary(aov_2way)[[1]][3, 3] # from the anova table
df_full_2 <- summary(aov_2way)[[1]][3, 1]
m <- 15
# Contrast 1 for males and females seperately
coefficients_1 <- c(-.5, -.5, 1)
SE_g1 <- sqrt(MSE_full_2) * sqrt(sum(coefficients_1^2/m)) # same for males and females
g1_male <- sum(coefficients_1 * mean_cond_male)
t1_male <- g1_male / SE_g1
p1_male <- 2 * min(pt(t1_male, df_full_2), 1 - pt(t1_male, df_full_2))
g1_female <- sum(coefficients_1 * mean_cond_female)
t1_female <- g1_female / SE_g1
p1_female <- 2 * min(pt(t1_female, df_full_2), 1 - pt(t1_female, df_full_2))
# Contrast 2 for males and females seperately
coefficients_2 <- c(-1, 1, 0)
SE_g2 <- sqrt(MSE_full_2) * sqrt(sum(coefficients_2^2/m)) # same for males and females
g2_male <- sum(coefficients_2 * mean_cond_male)
t2_male <- g2_male / SE_g2
p2_male <- 2 * min(pt(t2_male, df_full_2), 1 - pt(t2_male, df_full_2))
g2_female <- sum(coefficients_2 * mean_cond_female)
t2_female <- g2_female / SE_g2
p2_female <- 2 * min(pt(t2_female, df_full_2), 1 - pt(t2_female, df_full_2))
# Bonferroni correction on the 2 planned contrasts
bon_cor_four <- function (p_value) {
  p_bonferroni <- 0.05 / 4 # familywise alfa = 0.05, and P = 4
  bon <- p_value <= p_bonferroni
  return(bon) #Returns True when p-value is smaller than the bonferroni correction
}
# Creating a dataframe of the p-values with a boolean operator whether they are significant or not
p_val_contrasts <- c(p1_male, p2_male, p1_female, p2_female)
bonferroni_corrected_2 <- tapply(p_val_contrasts, c('p1_male', 'p2_male', 'p1_female', 'p2_female'), 
                                 bon_cor_four) # applying the function on the 2 p-values
bonferroni_corrected_2
# Contrast 1 is now only significant for the female group when we take in account the bonferroni 
correction
# p1_male = 0.034881, p1_female = 0.000017, p2_male = 0.812973, p2_female = 0.866648 (bon alfa = 0.05 / 4 = 0.0125)
# Bonferroni confidence intervals
CI_1_male <- data.frame('Confidence Interval' = 'Contrast 1 male',
                        
                        'Lower' = g1_male - (qt(p = 0.99375, df = df_full_2) * SE_g1), # 95% CI for contrast 1 for males with alfa/2P = 0.00625
                        
                        'Upper' = g1_male + (qt(p = 0.99375, df = df_full_2) * SE_g1))
CI_1_female <- data.frame('Confidence Interval' = 'Contrast 1 female',
                          
                          'Lower' = g1_female - (qt(p = 0.99375, df = df_full_2) * SE_g1),
                          
                          'Upper' = g1_female + (qt(p = 0.99375, df = df_full_2) * SE_g1))
CI_2_male <- data.frame('Confidence Interval' = 'Contrast 2 male',
                        
                        'Lower' = g2_male - (qt(p = 0.99375, df = df_full_2) * SE_g2),
                        
                        'Upper' = g2_male + (qt(p = 0.99375, df = df_full_2) * SE_g2))
CI_2_female <- data.frame('Confidence Interval' = 'Contrast 2 female',
                          
                          'Lower' = g2_female - (qt(p = 0.99375, df = df_full_2) * SE_g2),
                          
                          'Upper' = g2_female + (qt(p = 0.99375, df = df_full_2) * SE_g2))
conf_intervals_2 <- rbind(CI_1_male, CI_1_female, CI_2_male, CI_2_female)
conf_intervals_2
# Calculating partial omega squared for the 2 main effects and the interaction effect of the normal 2 way anova
SSA <- summary(aov_2way)[[1]][1, 2] 
SSB <- summary(aov_2way)[[1]][2, 2] 
MSE_full_int <- summary(aov_2way)[[1]][3, 3]
# Calculating partial omega squared for a main effect of condition 
partialomegasquaredA <- ((SSA - (a-1))* MSE_full_int) / ((SSA + (n - (a-1)))* MSE_full_int)
partialomegasquaredA
#calculating partial omega squared for a main effect of gender
#msefull2way <- summary(aov_2way)[[1]][3, 2] / (a*b)*(30-1) #calcuting mean sum of squares of the full 
model 
partialomegasquaredB <- ((SSB - (b-1))* MSE_full_int) / ((SSB + (n - (b-1)))* MSE_full_int)
partialomegasquaredB
# ASSUMPTION CHECKS for 2way
# Homoscedasticity
# Histogram of residuals
hist(aov_2way$residuals, main = 'Residuals', xlab = 'Residuals')
# Residual plot
ggplot(data, aes(x = as.factor(targetemregnames), y = aov_2way$residuals)) + 
  geom_jitter(width = 0.2, alpha = 0.5, aes(color = gendernames)) + 
  labs( x = "Fitted", y = "Residuals") +
  geom_hline(yintercept=0,linetype="dashed")+
  facet_wrap(~gendernames)
# Normality
# QQ plot
qqnorm(aov_2way$residuals) # plot residuals
qqline(aov_2way$residuals)
x <- seq(-5,5,len = 100) # plot standard normal function
lines(x,x,col="red")
#end of scrip
