install.packages('car')
install.packages("sjstats")
library(readxl)
groep20 <- read_excel("Desktop/groep20.xlsx")
condition = as.factor(groep20$targetemreg)
#################################
####### QUESTION NUMBER 1 #######
#################################
# ANOVA (here it's made by a function to do plots faster, later - manual version)
mod.aov = aov(groep20$appropriate ~ condition, data=groep20)
summary.lm(mod.aov) #Adjusted R-squared:0.1103 -> 11% of varience is explained by model,F(2,87)=6.517, p-value = 0.002305
effectsize::omega_squared(mod.aov) #w2=0.11
# Residual plot
plot(mod.aov$fitted.values,mod.aov$residuals, xlim= c(0,10), main = 'Residuals', xlab = 'Fitted',
     ylab = 'Residuals')
abline(h=0)
# Data plot
mcond = tapply(groep20$appropriate, condition, mean) #condition specific means
plot(groep20$appropriate ~ condition, ylab = "appropriateness",xlab = "condition")
abline(h = mean(groep20$appropriate), lty=2, col=2)
# Equal variance
library(car)
appropriate <- groep20$appropriate
leveneTest(appropriate ~ condition) # p-value = 0.8 > 0.05 then variances are homogeneous
# Normality of errors
qqnorm(mod.aov$residuals) # plot residuals
qqline(mod.aov$residuals)
x <- seq(-5,5,len = 100) # plot standard normal function
lines(x,x,col="red")
#and histogram
hist(mod.aov$residuals, main = 'Residuals', xlab = 'Residuals')
# Check for outliers
#to extract the row number corresponding to the outlier
boxplot(groep20$appropriate, plot=FALSE)$out #participant with level of 6.2 is outlier
out <- boxplot(groep20$appropriate, plot=FALSE)$out
out_ind <- which(groep20$appropriate %in% c(out))
groep20[out_ind, ] #what participant will be removed from the sample
#to see a boxplot
boxplot(groep20$appropriate,
        ylab = "Appropriateness",
        main = "Appropriateness of the person’s reaction")
mtext(paste("Outliers: ", paste(out, collapse = ", ")))
# to remove an outlier
outliers <- boxplot(groep20$appropriate, plot=FALSE)$out
groep20edited<-groep20
groep20edited<- groep20edited[-which(groep20edited$appropriate %in% outliers),] #new datasetwithout outlier
#to change condition factor according new dataset
condition_edited = as.factor(groep20edited$targetemreg)
#to check ANOVA without outlier
mod.aov = aov(groep20edited$appropriate ~ condition_edited, data=groep20)
summary.lm(mod.aov) # 11% of varience is explained by model, F(2,86)=5.559, p-value= 0.005363 -model still significant
# Manual Anova (with outlier)
# Split dataframe by experimental groups
control<-subset (groep20, condition=="1")
suppression<-subset (groep20, condition=="2")
expression<-subset (groep20, condition=="3")
l1 = length(control$appropriate)
l2 = length(suppression$appropriate)
l3 = length(expression$appropriate)
n <- l1 + l2 + l3
df_red = n-1 #red
df_full = n-3 #full
df_eff = df_red - df_full
mu_1 = mean(control$appropriate)
mu_2 = mean(suppression$appropriate)
mu_3 = mean(expression$appropriate)
mu=mean(c(mu_1,mu_2,mu_3))
se_1=var(control$appropriate)
se_2=var(suppression$appropriate)
se_3=var(expression$appropriate)
stdev_1 = sqrt(se_1)
stdev_2 = sqrt(se_2)
stdev_3 = sqrt(se_3)
sse_full = sum((control$appropriate- mu_1)^2)+sum ((suppression$appropriate - mu_2)^2)+sum
((expression$appropriate - mu_3)^2)
sse_red=sum((control$appropriate - mu)^2)+sum ((suppression$appropriate - mu)^2)+sum
((expression$appropriate- mu)^2)
sse_eff=sse_red - sse_full
Fvalue = (sse_eff/ df_eff) / (sse_full/ df_full) # 6.516
p = 1-pf(Fvalue, df_eff , df_full)
pf(Fvalue, df_eff, df_full, lower.tail = FALSE) # 0.00230547
#conclusion: significant effect
# Manual Anova (without outlier) to check if results differ
# Split dataframe by experimental groups
control_1<-subset (groep20edited, condition_edited=="1")
suppression_1<-subset (groep20edited, condition_edited=="2")
expression_1<-subset (groep20edited, condition_edited=="3")
l1_1 = length(control_1$appropriate)
l2_1 = length(suppression_1$appropriate)
l3_1 = length(expression_1$appropriate)
n_1 <- l1 + l2 + l3
df_red_1 = n-1 #red
df_full_1 = n-3 #full
df_eff_1 = df_red - df_full
mu_1_1 = mean(control_1$appropriate)
mu_2_1 = mean(suppression_1$appropriate) #has changed to 4.4
mu_3_1 = mean(expression_1$appropriate)
mu_1 = mean(c(control_1$appropriate,suppression_1$appropriate,expression_1$appropriate))
se_1_1 = var(control_1$appropriate)
se_2_1 = var(suppression_1$appropriate) #has changed to 0.48
se_3_1 = var(expression_1$appropriate)
stdev_1 = sqrt(se_1_1)
stdev_2 = sqrt(se_2_1)
stdev_3 = sqrt(se_3_1)
sse_full_1 = sum((control_1$appropriate- mu_1)^2)+sum ((suppression_1$appropriate -
                                                          mu_2)^2)+sum ((expression_1$appropriate - mu_3)^2)
sse_red_1=sum((control_1$appropriate - mu)^2)+sum ((suppression_1$appropriate - mu)^2)+sum
((expression_1$appropriate- mu)^2)
sse_eff_1=sse_red_1 - sse_full_1
Fvalue_1 = (sse_eff_1/ df_eff_1) / (sse_full_1/ df_full_1) #5.501
p = 1-pf(Fvalue_1, df_eff_1, df_full_1)
pf(Fvalue_1, df_eff_1, df_full_1, lower.tail = FALSE) # 0.0056
#conclusion that groups still differ and we can leave outlier in the model but we will still check
#contrasts when outlier is excluded
# Contrasts with outlier
# a) Examine whether the suppression condition differ from the other two conditions
mcond = tapply(groep20$appropriate, condition, mean) #condition specific means
MSE_full = sse_full/df_full #0.52
table = table(condition)
contrast1=c(-.5, 1, -.5) # coefficients
g1 = sum(contrast1 * mcond) # estimate 0.545
seg1 = sqrt(MSE_full) * sqrt(sum(contrast1^2/table) ) # standard error 0.161
t1 = g1/seg1 # t statistic 3.379
p1 = 2 * min(pt(t1, df_full), 1-pt(t1, df_full)) # two sided p value = 0.001
#conslusion - differences exist - response of individuals who suppressed their positive
#emotions would be judged as more appropriate than the response of people who express positive emotions and control group
# b) Examine whether the expression condition differ from the control condition
contrast2=c(-1, 0, 1) # coefficients
g2 = sum(contrast2 * mcond) # estimate -0.236
seg2 = sqrt(MSE_full) * sqrt(sum(contrast2^2/table)) # standard error 0.186
t2 = g2/seg2 # t statistic -1.270
p2 = 2 * min(pt(t2, df_full), 1-pt(t2, df_full)) # two sided p value 0.207
pk = 0.05/2 # 0.025 Bonferonni correction for 2 comparisons
# conclusion - no differences - people who express their positive emotions dont differ from control
group
# Contrast without outlier
# a) Examine whether the suppression condition differ from the other two conditions
mcond_1 = tapply(groep20edited$appropriate, condition_edited, mean) #condition specific means
MSE_full_1 = sse_full_1/df_full_1 #0.52
table_1 = table(condition_edited)
contrast1_1=c(-.5, 1, -.5) # coefficients
g1_1 = sum(contrast1_1 * mcond_1) # estimate 0.486
seg1_1 = sqrt(MSE_full_1) * sqrt(sum(contrast1_1^2/table_1) ) # standard error 0.157
t1_1 = g1_1/seg1_1 # t statistic 3.079
p1_1 = 2 * min(pt(t1_1, df_full_1), 1-pt(t1_1, df_full_1)) # two sided p value = 0.002
#conslusion - differences still exist - response of individuals who suppressed their positive
#emotions would be judged as more appropriate than the response of people who express positive emotions and control group
# b) Examine whether the expression condition differ from the control condition
contrast2_1=c(-1, 0, 1) # coefficients
g2_1 = sum(contrast2_1 * mcond_1) # estimate -0.236
seg2_1 = sqrt(MSE_full_1) * sqrt(sum(contrast2_1^2/table_1)) # standard error 0.180
t2_1 = g2_1/seg2_1 # t statistic -1.312
p2_1 = 2 * min(pt(t2_1, df_full_1), 1-pt(t2_1, df_full_1)) # two sided p value 0.192
# conclusion - still no differences - people who express their positive emotions dont differ from control group
# contrasts with and without outlier are the same
#################################
####### QUESTION NUMBER 2 #######
#################################
library(sjstats)
ibrary(dplyr)
# Check if the interaction is significant
gender = as.factor(groep20$gender)
condition = as.factor(groep20$targetemreg)
assesssment = groep20$appropriate
# Interaction plot
interaction.plot(gender,condition,assesssment, type = "b", pch=c(18,24,22), col=c(1,2,3))
# Is interaction significant?
groep20.aov1<-aov(assesssment ~ gender+condition + gender*condition)
summary(groep20.aov1) # Pr(>F) for gender:condition = 0.57819 -> NOT significant
effectsize::omega_squared(groep20.aov1) # for condition effect size w2=0.11
# Dropping the interaction
groep20.aov2<-aov(assesssment ~ gender+condition)
summary(groep20.aov2) ##### Pr(>F) for condition = 0.00236 -> significant
# Diagnostics
#Homogeneity of variances
library(car)
leveneTest(assesssment~condition) ##### Pr(>F) for condition = 0.8734>0.05 -> not reject Ho
#Normality of residuals
shapiro.test(groep20.aov2$residuals) ##### Pr(>F) = 0.403>0.05 -> not reject Ho