##############################################################
################ Data assignment #############################
##############################################################

# Clear work space 
rm(list = ls(all=TRUE))


#Load libraries
library(dplyr)
library(plyr)
library(tidyr)
library(readxl)
library(rstatix)
library(ggplot2)
library(car)
library(lsmeans)

# Set working directory 
setwd("")

# Load data file

data <- read_excel("base.xlsx")

data$targetemreg <- factor(data$targetemreg, 
                              levels = c('1', '2', '3'),
                              labels = c('control', 'suppression', 'expression'))

data$gender <- factor(data$gender, 
                              levels = c('1', '2'),
                              labels = c('men', 'women'))
data$ID <- 1:90

############################
# Preliminary information ##
############################

summary(data) # Summary of the data

# Plot of the group means 
means_group <- group_by(data, targetemreg, gender) %>% 
  dplyr::summarise(
  mean = mean(appropriate, na.rm = TRUE), 
  sd = sd(appropriate, na.rm = TRUE))
dev.off()
means_group %>% 
  ggplot() +
  aes(x = targetemreg, y = mean, color = gender) +
  geom_line(aes(group = gender)) +
  geom_point() +
  labs(colour = "Gender", y = 'Appropriateness', x = "Group") 


###########################
# Checking assumptions ###
###########################

model <- aov(appropriate ~  targetemreg*gender, data = data)


### Homogeneity of variances 
# Residual plot

plot(model$fitted.values, model$residuals, main = 'Residuals', xlab = 'Fitted', ylab = 'Residuals')
abline(h=0)

leveneTest(model)

#### Normality

# QQ-plot
qqnorm(model$residuals) 
qqline(model$residuals)
x <- seq(-5,5,len = 100) 
lines(x,x,col="red")

shapiro.test(data$appropriate)

# Histogram
hist(model$residuals, main = 'Residuals', xlab  = 'Residuals')

### Outlier

boxplot(appropriate ~ targetemreg*gender, data = data)

outlier <- data %>% 
  group_by(targetemreg, gender) %>%
  identify_outliers(appropriate)


###################
###### ANOVA #####
##################

# 2-way ANOVA with outliers
model <- aov(appropriate ~  targetemreg + gender + targetemreg * gender, data = data)
aov.summary <- summary(model)


# Contrasts
Contrast1 <- c(0.5,-1,0.5)
Contrast2 <- c(-1,0,1)

out_contr <- aov(appropriate ~  targetemreg + gender + 0, data = data)
lst <- lsmeans(out_contr, ~ targetemreg)

contr.summary1 <- lsmeans::contrast(lst, list(Contrast1))
contr.summary2 <- lsmeans::contrast(lst, list(Contrast2))


# 2-way ANOVA without outliers
data_o = subset(data,  !(data$ID %in% outlier$ID))
model_o <- aov(appropriate ~  targetemreg + gender + targetemreg * gender, data = data_o)
aov.summary <- summary(model_o)

# Contrasts
Contrast1 <- c(0.5,-1,0.5)
Contrast2 <- c(-1,0,1)

out_contr_o <- aov(appropriate ~  targetemreg + gender + 0, data = data_o)
lst_o <- lsmeans(out_contr_o, ~ targetemreg)

contr.summary1_o <- lsmeans::contrast(lst_o, list(Contrast1))
contr.summary2_o <- lsmeans::contrast(lst_o, list(Contrast2))

